SharedDispersion - LatentLego

Skip to content

# SharedDispersion

### `latent.layers.SharedDispersion`

Layer to get shared dispersion estimates per gene.

#### `__init__(self, units, name=None, activation='clipped_exp', initializer='glorot_normal')` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`units` | `int` | Positive integer, dimensionality of the output space. | required
`name` | `str` | String indicating the name of the layer. | `None`
`activation` | `Union[str, Callable]` | Activation function to use. | `'clipped_exp'`
`initializer` | `Union[str, Callable]` | Initializer for the `kernel` weights matrix. | `'glorot_normal'`